==> nextcloud-app-deck-1%3A0.6.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/he.js <==
OC.L10N.register(
    "deck",
    {
    "Remove user from card" : "הסרת משתמש מכרטיס",
    "Hours" : "שעות",
    "Minutes" : "דקות",
    "Maximum file size of {size} exceeded" : "גודל הקבצים המרבי {size} הושג",
    "Deck" : "חפיסה",
    "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
    "The board \"%s\" has been shared with you by %s." : "הלוח „%s” שותף אתך על ידי %s.",
    "{user} has shared the board %s with you." : "הלוח %s שותף אתך על ידי {user}",
    "No data was provided to create an attachment." : "לא סופקו נתונים ליצירת קובץ מצורף",
    "Finished" : "הסתיים",
    "To review" : "לסקירה",
    "Action needed" : "נדרשת פעולה",
    "Later" : "מאוחר יותר",
    "The file was uploaded" : "הקובץ הועלה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מההנחיה upload_max_filesize ב־php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שצוינה בטופס ה־HTML",
    "The file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "No file was uploaded" : "לא הועלה קובץ",
    "Missing a temporary folder" : "חסרה תיקייה זמנית",
    "Could not write file to disk" : "לא ניתן לכתוב לכונן",
    "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
    "No file uploaded or file size exceeds maximum of %s" : "לא הועלה אף קובץ או שגודל הקובץ חרג מהסף המרבי של %s",
    "A kanban style project and personal management tool for Nextcloud" : "כלי ניהול למיזמים או לדברים אישיים עבור Nextcloud",
    "Add a new stack" : "הוספת ערימה חדשה",
    "Submit" : "הגשה",
    "Show archived cards" : "הצגת כרטיסים בארכיון",
    "Hide archived cards" : "הסתרת כרטיסים בארכיון",
    "All Boards" : "כל הלוחות",
    "Archived boards" : "לוחות שנשמרו בארכיון",
    "Drop your files here to upload it to the card" : "ניתן להשליך את הקבצים שלך כאן כדי להעלות אותם לכרטיס",
    "Enter a card title" : "נא להקליד כותרת לכרטיס",
    "Add card" : "הוספת כרטיס",
    "Close" : "סגירה",
    "Sharing" : "שיתוף",
    "Tags" : "תגיות",
    "Select users or groups to share with" : "נא לבחור משתמשים או קבוצות לשתף אתם",
    "No matching user or group found." : "לא נמצא משתמש או קבוצה.",
    "Loading" : "בטעינה",
    "Edit" : "עריכה",
    "Share" : "שיתוף",
    "Manage" : "ניהול",
    "Discard share" : "התעלמות משיתוף",
    "Create" : "יצירה",
    "Create a new tag" : "יצירת תגית חדשה",
    "Status" : "מצב",
    "Title" : "כותרת",
    "Members" : "חברים",
    "More actions" : "פעולות נוספות",
    "Edit board" : "עריכת לוח",
    "Archive board" : "העברת לוח לארכיון",
    "Unarchive board" : "הוצאת ארכיון מהלוח",
    "Delete board" : "מחיקת לו",
    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "ביטול מחיקת לוח - אחרת הלוח יימחק במהלך ריצת ה־cronjob הבאה.",
    "Create new board" : "יצירת לוח חדש",
    "New board title" : "כותרת לוח חדשה",
    "Select an attachment" : "נא לבחור קובץ מצורף",
    "Cancel upload" : "ביטול העלאה",
    "by" : "מאת",
    "Undo file deletion - Otherwise the file will be deleted during the next cronjob run." : "ביטול מחיקת קובץ - אחרת הקובץ יימחק עם ריצת משימת ה־cron הבאה.",
    "Undo file deletion" : "ביטול מחיקת קובץ",
    "Insert the file into the description" : "הוספת הקובץ לתיאור",
    "Modified:" : "מועד השינוי",
    "Created:" : "מועד היצירה:",
    "Choose a tag" : "נא לבחור תגית",
    "Add a tag" : "הוספת תגית",
    "Select tags" : "בחירת תגיות",
    "Assign users" : "הקצאת משתמשים",
    "Choose a user to assign" : "נא לבחור משתמש להקצאה",
    "Assign this card to a user" : "הקצאת הכרטיס הזה למשתמש",
    "Due date" : "מועד תפוגה",
    "Click to set" : "יש ללחוץ להגדרה",
    "Remove due date" : "הסרת מועד התפוגה",
    "Description" : "תיאוג",
    "Attachments" : "קבצים מצורפים",
    "Saved" : "נשמר",
    "Unsaved changes" : "שינויים שלא נשמרו",
    "Insert attachment" : "הוספת קובץ מצורף",
    "Formatting help" : "עזרה בסידור בתבנית",
    "Upload attachment" : "העלאת קבצים מצורפים",
    "Add a card description…" : "הוספת תיאור כרטיס…",
    "Shared boards" : "לוחות משותפים",
    "Move board to archive" : "העברת לוח לארכיון",
    "Create a new board" : "יצירת לוח חדש"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-app-deck-1%3A0.8.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/he.js <==
OC.L10N.register(
    "deck",
    {
    "Remove user from card" : "הסרת משתמש מכרטיס",
    "Hours" : "שעות",
    "Minutes" : "דקות",
    "Maximum file size of {size} exceeded" : "גודל הקבצים המרבי {size} הושג",
    "File already exists" : "הקובץ כבר קיים",
    "Deck" : "חפיסה",
    "Personal" : "אישי",
    "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
    "The board \"%s\" has been shared with you by %s." : "הלוח „%s” שותף אתך על ידי %s.",
    "{user} has shared the board %s with you." : "הלוח %s שותף אתך על ידי {user}",
    "No data was provided to create an attachment." : "לא סופקו נתונים ליצירת קובץ מצורף",
    "Finished" : "הסתיים",
    "To review" : "לסקירה",
    "Action needed" : "נדרשת פעולה",
    "Later" : "מאוחר יותר",
    "Done" : "הסתיים",
    "The file was uploaded" : "הקובץ הועלה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מההנחיה upload_max_filesize ב־php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שצוינה בטופס ה־HTML",
    "The file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "No file was uploaded" : "לא הועלה קובץ",
    "Missing a temporary folder" : "חסרה תיקייה זמנית",
    "Could not write file to disk" : "לא ניתן לכתוב לכונן",
    "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
    "No file uploaded or file size exceeds maximum of %s" : "לא הועלה אף קובץ או שגודל הקובץ חרג מהסף המרבי של %s",
    "A kanban style project and personal management tool for Nextcloud" : "כלי ניהול למיזמים או לדברים אישיים עבור Nextcloud",
    "Add a new stack" : "הוספת ערימה חדשה",
    "Submit" : "הגשה",
    "Show archived cards" : "הצגת כרטיסים בארכיון",
    "Hide archived cards" : "הסתרת כרטיסים בארכיון",
    "All Boards" : "כל הלוחות",
    "Archived boards" : "לוחות שנשמרו בארכיון",
    "Actions" : "פעולולת",
    "Drop your files here to upload it to the card" : "ניתן להשליך את הקבצים שלך כאן כדי להעלות אותם לכרטיס",
    "Archive card" : "העברת כרטיס לארכיון",
    "Delete card" : "מחיקת כרטיס לארכיון",
    "Enter a card title" : "נא להקליד כותרת לכרטיס",
    "Add card" : "הוספת כרטיס",
    "Close" : "סגירה",
    "Sharing" : "שיתוף",
    "Tags" : "תגיות",
    "Select users or groups to share with" : "נא לבחור משתמשים או קבוצות לשתף אתם",
    "Group" : "קבוצה",
    "No matching user or group found." : "לא נמצא משתמש או קבוצה.",
    "Loading" : "בטעינה",
    "Edit" : "עריכה",
    "Share" : "שיתוף",
    "Manage" : "ניהול",
    "Discard share" : "התעלמות משיתוף",
    "Create" : "יצירה",
    "Create a new tag" : "יצירת תגית חדשה",
    "Status" : "מצב",
    "Title" : "כותרת",
    "Members" : "חברים",
    "More actions" : "פעולות נוספות",
    "Edit board" : "עריכת לוח",
    "Archive board" : "העברת לוח לארכיון",
    "Unarchive board" : "הוצאת ארכיון מהלוח",
    "Delete board" : "מחיקת לו",
    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "ביטול מחיקת לוח - אחרת הלוח יימחק במהלך ריצת ה־cronjob הבאה.",
    "Create new board" : "יצירת לוח חדש",
    "New board title" : "כותרת לוח חדשה",
    "Create board" : "יצירת לוח",
    "Select an attachment" : "נא לבחור קובץ מצורף",
    "Cancel upload" : "ביטול העלאה",
    "by" : "מאת",
    "Undo file deletion - Otherwise the file will be deleted during the next cronjob run." : "ביטול מחיקת קובץ - אחרת הקובץ יימחק עם ריצת משימת ה־cron הבאה.",
    "Undo file deletion" : "ביטול מחיקת קובץ",
    "Insert the file into the description" : "הוספת הקובץ לתיאור",
    "Modified:" : "מועד השינוי",
    "Created:" : "מועד היצירה:",
    "Choose a tag" : "נא לבחור תגית",
    "Add a tag" : "הוספת תגית",
    "Select tags" : "בחירת תגיות",
    "Assign users" : "הקצאת משתמשים",
    "Choose a user to assign" : "נא לבחור משתמש להקצאה",
    "Assign this card to a user" : "הקצאת הכרטיס הזה למשתמש",
    "Due date" : "מועד תפוגה",
    "Click to set" : "יש ללחוץ להגדרה",
    "Remove due date" : "הסרת מועד התפוגה",
    "Description" : "תיאוג",
    "Attachments" : "קבצים מצורפים",
    "Saved" : "נשמר",
    "Unsaved changes" : "שינויים שלא נשמרו",
    "Insert attachment" : "הוספת קובץ מצורף",
    "Formatting help" : "עזרה בסידור בתבנית",
    "Upload attachment" : "העלאת קבצים מצורפים",
    "Add a card description…" : "הוספת תיאור כרטיס…",
    "Shared boards" : "לוחות משותפים",
    "Move board to archive" : "העברת לוח לארכיון",
    "Create a new board" : "יצירת לוח חדש",
    "Settings" : "הגדרות"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
